Method: Masscan::Parsers::List.open

Defined in:
lib/masscan/parsers/list.rb

.open(path) {|file| ... } ⇒ File

Opens a list file for parsing.

Parameters:

  • path (String)

    The path to the file.

Yields:

  • (file)

    If a block is given, it will be passed the opened file. Once the block returns, the file will be closed.

Yield Parameters:

  • file (File)

    The opened file.

Returns:

  • (File)

    If no block was given, the opened file will be returned.



33
34
35
# File 'lib/masscan/parsers/list.rb', line 33

def self.open(path,&block)
  File.open(path,&block)
end